default_prefix = "BISON"

known_chains = {
    "SHAREBERRY": {
        "chain_id": "a3ee3a34dd82dcd8e4f9ed14202c6d35734ea4c8d9c0e9daee48ec859d135b6c",
        "prefix": "SHARE",
        "steem_symbol": "SHPO",
        "sbd_symbol": "UNDEFINED",
        "vests_symbol": "VESTS",
    },
}
